# Contribution Guidelines

At present, there isn't a lot of communication about this project and we would like to change that! We aim to spread a word about NLP Profiler to the wider community. If you are interested please go through the below-mentioned pointers:

(a) widely recommended, regardless of personal opinion

(b) discussed in the community (mentioned via social media)

(c) a good starting point for the subject or related subjects (contains examples)

(d) implementations that would be a good example for everyone to follow and be inspired by

(e) please provide easy to read code and documentation with it, examples are a great form of documentation

(f) please provide tests along with your implementation changes


## Pull Requests 

At the moment it's we are open to these kinds of high-level ideas and contributions:

- Feature enhancement
- Bug reports
- Documentation enhancements
- Notebook enhancements
- Anything else that helps with the improvement of the library for the community using it

Furthermore, please ensure your pull request follows the following guidelines:

* Please search previous suggestions before making a new one, as yours may be a duplicate.
* Please make an individual pull request for each suggestion.
* Make sure your text editor is set to remove trailing whitespace.

See [Developer guide](#developer-guide.md) for more specific details.

Thank you for your suggestions!

---

Return to [README.md](README.md)
